@@ -19,12 +19,14 @@ from cybrid_api_bank.api.assets_bank_api import AssetsBankApi
 from cybrid_api_bank.api.banks_bank_api import BanksBankApi
 from cybrid_api_bank.api.customers_bank_api import CustomersBankApi
 from cybrid_api_bank.api.deposit_addresses_bank_api import DepositAddressesBankApi
+from cybrid_api_bank.api.deposit_bank_accounts_bank_api import DepositBankAccountsBankApi
 from cybrid_api_bank.api.external_bank_accounts_bank_api import ExternalBankAccountsBankApi
 from cybrid_api_bank.api.external_wallets_bank_api import ExternalWalletsBankApi
 from cybrid_api_bank.api.identity_verifications_bank_api import IdentityVerificationsBankApi
+from cybrid_api_bank.api.invoices_bank_api import InvoicesBankApi
+from cybrid_api_bank.api.payment_instructions_bank_api import PaymentInstructionsBankApi
 from cybrid_api_bank.api.prices_bank_api import PricesBankApi
 from cybrid_api_bank.api.quotes_bank_api import QuotesBankApi
-from cybrid_api_bank.api.rewards_bank_api import RewardsBankApi
 from cybrid_api_bank.api.symbols_bank_api import SymbolsBankApi
 from cybrid_api_bank.api.trades_bank_api import TradesBankApi
 from cybrid_api_bank.api.transfers_bank_api import TransfersBankApi
