@@ -22,6 +22,7 @@ from cybrid_api_bank.model.bank_list import BankList
 from cybrid_api_bank.model.bank_type import BankType
 from cybrid_api_bank.model.customer import Customer
 from cybrid_api_bank.model.customer_address import CustomerAddress
+from cybrid_api_bank.model.customer_aliases_inner import CustomerAliasesInner
 from cybrid_api_bank.model.customer_list import CustomerList
 from cybrid_api_bank.model.customer_name import CustomerName
 from cybrid_api_bank.model.customer_state import CustomerState
@@ -79,6 +80,7 @@ from cybrid_api_bank.model.post_external_bank_account_counterparty_address impor
 from cybrid_api_bank.model.post_external_bank_account_counterparty_bank_account import PostExternalBankAccountCounterpartyBankAccount
 from cybrid_api_bank.model.post_external_bank_account_counterparty_name import PostExternalBankAccountCounterpartyName
 from cybrid_api_bank.model.post_external_wallet import PostExternalWallet
+from cybrid_api_bank.model.post_fee import PostFee
 from cybrid_api_bank.model.post_identification_number import PostIdentificationNumber
 from cybrid_api_bank.model.post_identity_verification import PostIdentityVerification
 from cybrid_api_bank.model.post_identity_verification_address import PostIdentityVerificationAddress
